========
Glossary
========

This glossary offers a list of terms and definitions to define a
vocabulary for Cinder concepts.

.. glossary::

    Logical Volume Manager (LVM)

        Provides a method of allocating space on mass-storage
        devices that is more flexible than conventional partitioning
        schemes.

    iSCSI Qualified Name (IQN)

        IQN is the format most commonly used for iSCSI names, which uniquely
        identify nodes in an iSCSI network.
        All IQNs follow the pattern iqn.yyyy-mm.domain:identifier, where
        'yyyy-mm' is the year and month in which the domain was registered,
        'domain' is the reversed domain name of the issuing organization, and
        'identifier' is an optional string which makes each IQN under the same
        domain unique. For example, 'iqn.2015-10.org.openstack.408ae959bce1'.
